Learn R Programming

AGHmatrix (version 3.0.1)

datatreat: Organizes pedigree data in a chronological way using C++

Description

This function organizes pedigree data in a chronological way and returns a list: i) parental 1 values (numeric); ii) parental 2 values (numeric); iii) individual names. Also saves a `.txt` file if `save = TRUE`.

Usage

datatreat(data = NULL, n.max = 50, unk = 0, save = FALSE)

Value

A list with elements: sire (numeric), dire (numeric), ind_data (names)

Arguments

data

A 3-column data frame or matrix with individual, sire, and dam

n.max

Max number of iterations (default = 50)

unk

Code for unknown parent (default = 0)

save

If TRUE, saves the reordered pedigree to a text file

Author

Rodrigo R. Amadeu rramadeu@gmail.com

Thiago de Paula Oliveira

Examples

Run this code
# data(ped.mrode)
# datatreat(ped.mrode)

Run the code above in your browser using DataLab